******************
Command-line tools
******************

conda_envfile_merge
===================

.. argparse::
    :module: conda_envfile
    :func: _conda_envfile_merge_parser
    :prog: conda_envfile_merge
